import Vue from 'vue';
import Vuex from 'vuex';

Vue.use(Vuex);

const store = new Vuex.Store({
	state() {
		return {
			//当前操作的商品(QS)
			currentGoods: {},
			//购物车数组
			shoppingCart: [],
			//门店商品列表
			foodArray: [],
			//预支付信息
			advancePayment: {
				totalPrice: 0,
				orderNumber: '',	//订单编号
			},
			//当前门店
			currentStore: {
				id: '',
				store_Name: '默认门店',
				toUserDistance: 9999
			},
			//上一次选择的门店
			lastCurrentStore: {},
			//当前可用优惠券列表
			currentUseCouponList: [],
			isLoginSuccess: false,
			//是否为会员
			isVipMember: false,
			//是否为特价
			isSpecialOffer: false,
			//本次扫码信息
			codeScanInfo: {
				storeId: '',	//门店ID
				deskCode: 0,	//桌号
				activityId: ''	//活动ID
			},
			//用户自动参与活动JSON数据
			userAutoActivityJson: null,
			//用户加钱换购JSON数据
			userExchangePriceJson: [],
			//门店风格
			storeStyles: []
		}
	},
	getters: {
		shopCartCount(state, getters) {
			let count = 0;
			state.shoppingCart.forEach(item => {
				if(item.count > 0) {
					count += item.count;
				}
			});
			return count;
		},
		shopCartTotalPrice(state, getters) {
			let price = 0;
			state.shoppingCart.forEach(food => {
				state.isVipMember ? price += (food.vipPrice * 100 * food.count) : price += (food.price * 100 * food.count);
				food.addtoFoodList?.forEach(feed => {
					feed.foods.forEach(addFood => {
						if (addFood.count > 0) {
							price += (addFood.count * addFood.price * 100);
						}
					});
				});
			});
			return price / 100;
		}
	},
	mutations: {
		onInitChooseStore(state, payload) {
			state.currentStore = payload;
		},
		onInitLastStore(state, payload) {
			state.lastCurrentStore = payload;
		},
		//初始化当前操作的商品
		initCurrentGoods(state, payload) {
			let currentGoods = payload;
			state.currentGoods = currentGoods;
		},
		//配料+1
		onFeedCountPlus(state, payload) {
			let feed = payload;
			state.currentGoods.addtoFoodList?.forEach(item => {
				item.foods.forEach(addFood => {
					if (addFood.id === feed.id) {
						addFood.count += 1;
						addFood.sourceCount = addFood.count;
						state.currentGoods.sencondId = state.currentGoods.sencondId.concat(feed.id);
					}
				});
			});
		},
		//配料-1
		onFeedCountReduce(state, payload) {
			let feed = payload;
			if (feed.count === 0) return;
			state.currentGoods.addtoFoodList.forEach(item => {
				item.foods.forEach(addFood => {
					if (addFood.id === feed.id) {
						addFood.count -= 1;
						addFood.sourceCount = addFood.count;
						state.currentGoods.sencondId = state.currentGoods.sencondId.replace(addFood.id, '');
					}
				});
			});
		},
		//套餐-1
		onSetMealCountReduce(state, payload) {
			const setMeal = payload;
			if (setMeal.count === 0) return;
			state.currentGoods.setMealList.forEach(item =>{
				item.foods.forEach(addFood => {
					if (addFood.id === setMeal.id) {
						addFood.count -= 1;
						addFood.sourceCount = addFood.count;
						state.currentGoods.sencondId = state.currentGoods.sencondId.concat(addFood.id);
					}
				})
			});
		},
		//套餐+1
		onSetMealCountPlus(state, payload) {
			const setMeal = payload;
			state.currentGoods.setMealList.forEach(item =>{
				item.foods.forEach(addFood => {
					if (addFood.id === setMeal.id) {
						addFood.count += 1;
						addFood.sourceCount = addFood.count;
						state.currentGoods.sencondId = state.currentGoods.sencondId.replace(addFood.id, '');
					}
				})
			});
		},
		//从购物车添加主食
		onStapleFoodPlusFromCart(state, payload) {
			let stapleFood = payload;
			let index = state.shoppingCart.findIndex(item => item.sencondId === stapleFood.sencondId);
			state.shoppingCart[index].count++;
			state.shoppingCart[index].addtoFoodList?.forEach(item => {
				item.foods[0].count += item.foods[0].sourceCount;
			});
			this.commit('onOperatorFoodArray', {
				id: state.shoppingCart[index].id,
				opertor: 'add'
			});
		},
		//从配料列表弹窗添加主食
		onStapleFoodPlusFromList(state, payload) {
			//从配料弹窗点击选好了，添加主食
			let index = state.shoppingCart.findIndex(item => item.sencondId === state.currentGoods.sencondId);
			//如果主食相同、配料相同，将主食数量+1
			if (index >= 0) {
				state.shoppingCart[index].count++;
			} else {	//如果主食相同，配料不相同
				let food = JSON.parse(JSON.stringify(state.currentGoods));
				food.count = 1;
				state.shoppingCart.push(food);
			}
			this.commit('onOperatorFoodArray', {
				id: state.currentGoods.id,
				opertor: 'add'
			});
		},
		//主食数量减1
		onStapleFoodReduce(state, payload) {
			let food = payload;
			let index = state.shoppingCart.findIndex(item => item.sencondId === food.sencondId);
			if (index >= 0) {
				this.commit('onOperatorFoodArray', {
					id: state.shoppingCart[index].id,
					opertor: 'reduce'
				});
				if (state.shoppingCart[index].count > 1) {
					state.shoppingCart[index].count--;
					state.shoppingCart[index].addtoFoodList?.forEach(item => {
						item.foods[0].count -= item.foods[0].sourceCount;
					});
				} else {
					state.shoppingCart.splice(index, 1);
				}
			}
		},
		//操作当前商品列表数据
		onOperatorFoodArray(state, payload) {
			let foodId = payload.id;
			let operator = payload.opertor;
			let isEnd = false;
			state.foodArray.forEach( classification => {
				if (!isEnd) {
					classification.foods.forEach(food => {
						if (food.id === foodId) {
							operator === 'add' ? food.shopCartNumber += 1 : food.shopCartNumber -= 1;
							isEnd = true;
							return;
						}
					});
				} else {
					return;
				}
			});
		},
		//初始化商品列表
		initFoodArray(state, payload) {
			state.foodArray = [];
			state.foodArray = payload;
		},
		//清空购物车
		onClearShopCart(state) {
			state.shoppingCart = [];
			state.foodArray.forEach( classification => {
				classification.foods.forEach(food => {
					food.shopCartNumber = 0;
				});
			});
		},
		//初始化订单编号
		onInitOrderNumber(state, payload) {
			state.advancePayment.orderNumber = payload;
		},
		//初始化预付总金额
		onInitAdvancePrice(state, payload) {
			state.advancePayment.totalPrice = payload;
		},
		//初始化当前可用优惠券列表
		initCurrentUseCouponList(state, payload) {
			payload.forEach(item => {
				item.isSelect = false;
			});
			state.currentUseCouponList = payload;
		},
		//优惠券复选框状态变化
		onCurrentCheckedChange(state, payload) {
			let checkedArr = payload;
			state.currentUseCouponList.forEach(item => {
				item.isSelect = false;
			});
			state.currentUseCouponList.forEach(item => {
				checkedArr.forEach(checkedId => {
					if (item.id == checkedId) {
						item.isSelect = true;
					} else {
						item.isSelect = false
					}
				});
			});
		},
		onChangeLoginState(state, payload) {
			state.isLoginSuccess = payload;
		},
		onChangeUserIsVip(state, payload) {
			state.isVipMember = payload;
		},
		onChangeIsSpecialOffer(state, payload) {
			state.isSpecialOffer = payload;
		},
		onInitScanInfo(state, payload) {
			state.codeScanInfo = {
				storeId: payload.storeId == null ? state.codeScanInfo.storeId : payload.storeId,	
				deskCode: payload.deskCode == null ? state.codeScanInfo.deskCode : payload.deskCode,
			};
		},
		//修改用户自动参与活动JSON数据
		onInitUserAutoActivityJson(state, payload) {
			state.userAutoActivityJson = payload;
		},
		//清空用户自动参与活动JSON数据
		onClearUserAutoActivityJson(state) {
			state.userAutoActivityJson = null;
		},
		//新增用户换购商品JSON
		inserUserExchangePriceJson(state, payload) {
			state.userExchangePriceJson.push(payload);
		},
		//删除用户换购商品JSON
		deleteUserExchangePriceJson(state, payload) {
			let delIndex = state.userExchangePriceJson.findIndex(item => item.goodsId === payload.id);
			if (delIndex > -1) {
				state.userExchangePriceJson.splice(delIndex, 1);
			}
		},
		//清空用户换购商品JSON
		clearUserExchangePriceJson(state) {
			state.userExchangePriceJson = [];
		},
		//设置门店风格
		onSetStoreStyles(state, payload) {
			state.storeStyles = payload;
		}
	}
});

export default store;